@@ -1,4 +1,4 @@
 # ignore import but unsed warning (W0611)
 # pylama:ignore=W0611
-from . import tasks
+from .tasks import community, login_logout, task_base
 from .task_executor import FinishEstimator, TaskExecutor
